@@ -50,6 +50,7 @@ except:
     import json
 import sys
 import bfsource
+#import connect
 import os
 from PyQt4 import QtCore
 from PyQt4.QtCore import Qt
@@ -74,6 +75,7 @@ class MainWindow(QtGui.QMainWindow):
         
         #print"Debugger: \n\n"
         self.ui.showFullScreen()
+        self.ui.activate.hide()
         self.ui.showbutton.hide()
         self.ui.search.clicked.connect(self.get_list)
         self.ui.activate.toggled.connect(self.set_as_default)
@@ -81,35 +83,30 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.hidebutton.clicked.connect(self.hideui)
         self.ui.showbutton.clicked.connect(self.releaseui)
         self.ui.banner.clicked.connect(self.information)
+        self.ui.minimize.clicked.connect(self.minimizefunc)
         self.ui.statsshow.setReadOnly(True)
         #self.ui.playername.home(True)
         #self.ui.playername.returnPressed(self.get_list)
-        if os.path.isfile("defaultplayer.ini"):
+        #if os.path.isfile("defaultplayer.ini"):
             #print"defaultplayer.ini is in path"
-            pass
-        else:
+            #pass
+        #else:
             #print"Directory created"
-            try:
-                os.makedirs("/home/user/MyDocs/.bfbc2stats/")
-            except:
-                pass    
+        try:
+            os.makedirs("/home/user/MyDocs/.bfbc2stats/")
+        except:
+            pass    
         
         #Üperprüfen, ob defaultplayer.txt vorhanden ist.Falls ja, Inhalt überprüfen.Wenn Inhalt leer, pass, wenn Inhalt vorhanden, laden
-        if os.path.isfile("defaultplayer.ini") or os.path.isfile("/home/user/MyDocs/.bfbc2stats/defaultplayer.ini"):
-            try:
-                #print"Try Maemo path"
-                f=open("/home/user/MyDocs/.bfbc2stats/defaultplayer.ini")
-                defpl="/home/user/MyDocs/.bfbc2stats/defaultplayer.ini"
-                f.close()
-            except:
-                #print"Take PC path"
-                defpl="defaultplayer.ini"    
-            if os.lstat(defpl).st_size > 0:
+        if os.path.isfile("/home/user/MyDocs/.bfbc2stats/defaultplayer.ini"):
+           
+             
+            if os.lstat("/home/user/MyDocs/.bfbc2stats/defaultplayer.ini").st_size > 0:
                 userdata={}
-                try:
-                    fobj=open("/home/user/MyDocs/.bfbc2stats/defaultplayer.ini","r")
-                except:    
-                    fobj=open("defaultplayer.ini","r")
+                #try:
+                fobj=open("/home/user/MyDocs/.bfbc2stats/defaultplayer.ini","r")
+                #except:    
+                    #fobj=open("defaultplayer.ini","r")
                 for line in fobj:
                     zuordnung=line.split()
                     userdata[zuordnung[0]]=zuordnung[1]
@@ -119,20 +116,21 @@ class MainWindow(QtGui.QMainWindow):
                 setplatform=userdata["setplatform"]
                 index=userdata["index"]
                 self.ui.playername.setText(setplayername)
-                #print"read from defaultplayer.ini"
+                print"read from defaultplayer.ini"
                 self.ui.statsshow.clear()
                 self.ui.activate.setChecked(True)
                 self.get_stats_general(userdata)
                 try:
-                    #print"read from bfbc2statscache.ini"
-                    try:
-                        fobj=open("/home/user/MyDocs/.bfbc2stats/bfbc2statscache.ini","r")
-                    except:    
-                        fobj=open("bfbc2statscache.ini","r")
+                    print"read from bfbc2statscache.ini"
+                    #try:
+                    fobj=open("/home/user/MyDocs/.bfbc2stats/bfbc2statscache.ini","r")
+                    #except:    
+                        #fobj=open("bfbc2statscache.ini","r")
                     cachetext=fobj.read()
                     self.ui.statsshow.setText(cachetext)
                     fobj.close()
                 except:
+                    print"except1"
                     pass    
                 
 
@@ -141,7 +139,8 @@ class MainWindow(QtGui.QMainWindow):
                
             else:
                 pass
-                self.ui.statsshow.setText("No userdata available!")   
+                self.ui.statsshow.setText("No userdata available!")  
+                 
                  
     def hideui(self):
         #print"Fullscreen activated"
@@ -162,7 +161,8 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.search.show()      
 
         
-    def get_list(self): 
+    def get_list(self):
+        #import connect 
         index=self.ui.platform.currentIndex()
         #print index
         setplatform=self.ui.platform.currentText()
@@ -395,10 +395,10 @@ class MainWindow(QtGui.QMainWindow):
         activatestate=self.ui.activate.checkState()
         if activatestate==False:
             #print "Deaktivated"
-            try:
-                default=open("/home/user/MyDocs/.bfbc2stats/defaultplayer.ini","w")
-            except:    
-                default=open("defaultplayer.ini","w")
+            
+            default=open("/home/user/MyDocs/.bfbc2stats/defaultplayer.ini","w")
+               
+            #default=open("defaultplayer.ini","w")
             default.write("")
             default.close
         else:
@@ -413,10 +413,10 @@ class MainWindow(QtGui.QMainWindow):
                 self.ui.activate.setChecked(False)
             else:
                 #print"Userdatei schreiben"
-                try:
-                    default=open("/home/user/MyDocs/.bfbc2stats/bfbc2statsinformation.ini")
-                except:    
-                    default=open("defaultplayer.ini","w")
+                #try:
+                default=open("/home/user/MyDocs/.bfbc2stats/bfbc2statsinformation.ini","w")
+                #except:    
+                    #default=open("defaultplayer.ini","w")
                
                 userdata={"setplayername":setplayername, 
                           "setplatform":setplatform,
@@ -431,10 +431,10 @@ class MainWindow(QtGui.QMainWindow):
                   
                 cache=self.ui.statsshow.toPlainText()
                 if cache!="":
-                    try:
-                        fobj=open("/home/user/MyDocs/.bfbc2stats/bfbc2statscache.ini","w")
-                    except:    
-                        fobj=open("bfbc2statscache.ini","w")
+                    #try:
+                    fobj=open("/home/user/MyDocs/.bfbc2stats/bfbc2statscache.ini","w")
+                    #except:    
+                        #fobj=open("bfbc2statscache.ini","w")
                     fobj.write(cache)
                     fobj.close()
                 else:
@@ -442,24 +442,25 @@ class MainWindow(QtGui.QMainWindow):
                 
 
     def information(self):
+        #import connect
         
         try:
             getinfo=urllib.urlopen("http://nachbar90.alfahosting.org/bfbc2stats/information.ini")
             getinformation=getinfo.read()
             self.ui.statsshow.setText(str(getinformation))
-            try:
-                fobj=open("/home/user/MyDocs/.bfbc2stats/bfbc2statsinformation.ini","w")
-            except:     
-                fobj=open("bfbc2statsinformation.ini","w")
+            #try:
+            fobj=open("/home/user/MyDocs/.bfbc2stats/bfbc2statsinformation.ini","w")
+            #except:     
+                #fobj=open("bfbc2statsinformation.ini","w")
             fobj.write(getinformation)
             fobj.close()
         except:
             
-            if os.path.isfile("bfbc2statsinformation.ini") or os.path.isfile("/home/user/MyDocs/.bfbc2stats/bfbc2statsinformation.ini"):
-                try:
-                    fobj=open("/home/user/MyDocs/.bfbc2stats/bfbc2statsinformation.ini")
-                except:    
-                    fobj=open("bfbc2statsinformation.ini","r") 
+            if os.path.isfile("/home/user/MyDocs/.bfbc2stats/bfbc2statsinformation.ini"):
+                #try:
+                fobj=open("/home/user/MyDocs/.bfbc2stats/bfbc2statsinformation.ini","r")
+                #except:    
+                    #fobj=open("bfbc2statsinformation.ini","r") 
                 information=fobj.read()
                 self.ui.statsshow.setText(information)
                 fobj.close()
@@ -470,6 +471,9 @@ class MainWindow(QtGui.QMainWindow):
                 self.ui.statsshow.setText("No internet connection established")             
             
             
+    def minimizefunc(self):#Experimentell, schließt statt zu minimieren
+        subprocess.Popen(['dbus-send', '--type=signal', '--session', '/com/nokia/hildon_desktop', 'com.nokia.hildon_desktop.exit_app_view'])        
+            
     def closefunc(self):#Methode zum Schließen des Mainwindows
         sys.exit()
             
